package com.iotechn.unimall.admin.api.sys;

import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.dto.ExpressBusinessDTO;
import com.iotechn.unimall.data.dto.SettlementManagementDTO;
import com.iotechn.unimall.data.model.Page;
import com.iotechn.unimall.data.domain.ExpressBillDO;
import com.iotechn.unimall.data.dto.ExpressBillDTO;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@HttpOpenApi(group = "admin.expressbill", description = "unimall_express_billService")
public interface ExpressBillService {

    @HttpMethod(description = "删除", permission = "expressBill:expressbill:delete", permissionParentName = "其他", permissionName = "ExpressBill")
    public boolean delete(
            @NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "id") Long id,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;


    @HttpMethod(description = "查询", permission = "expressBill:expressbill:list", permissionParentName = "其他", permissionName = "ExpressBill")
    public Page<ExpressBillDO> list(
            @HttpParam(name = "ExpressBillDTO", type = HttpParamType.COMMON, description = "ExpressBillDTO") ExpressBillDTO selectDTO,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "expressBill:expressbill:create", permissionParentName = "其他", permissionName = "ExpressBill")
    public ExpressBillDO create(
            @HttpParam(name = "ExpressBillDTO", type = HttpParamType.COMMON, description = "ExpressBillDTO") ExpressBillDTO insertDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "编辑", permission = "expressBill:expressbill:edit", permissionParentName = "其他", permissionName = "ExpressBill")
    public String edit(
            @HttpParam(name = "ExpressBillDTO", type = HttpParamType.COMMON, description = "ExpressBillDTO") ExpressBillDTO editDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;


    @HttpMethod(description = "添加", permission = "expressBill:expressbill:createAll", permissionParentName = "其他", permissionName = "ExpressBill")
    public void createAll(
            @HttpParam(name = "ExpressBillDTO", type = HttpParamType.COMMON, description = "ExpressBillDTO") List<ExpressBillDTO> expressBillDTOS) throws ServiceException;

    @HttpMethod(description = "导出", permission = "expressBill:expressbill:export", permissionParentName = "其他", permissionName = "ExpressBill")
    public String export(
            @HttpParam(name = "ExpressBillDTO", type = HttpParamType.COMMON, description = "ExpressBillDTO") ExpressBillDTO expressBillDTO,
            @HttpParam(name = "HttpServletResponse", type = HttpParamType.COMMON, description = "response") HttpServletResponse response) throws Exception;



}