package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.ExpressBusinessDO;
import com.iotechn.unimall.data.dto.ExpressBusinessDTO;
import com.iotechn.unimall.data.dto.SettlementManagementDTO;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.ExpressBillDO;
import com.iotechn.unimall.data.dto.ExpressBillDTO;
import com.iotechn.unimall.data.mapper.ExpressBillMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import tk.mybatis.mapper.util.StringUtil;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class ExpressBillServiceImpl implements ExpressBillService {

    @Autowired
    private ExpressBillMapper expressBillMapper;

    @Override
    public boolean delete(Long id,  Long adminId) throws ServiceException {
        return expressBillMapper.deleteById(id) > 0;
    }

    @Override
    public Page<ExpressBillDO> list(ExpressBillDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<ExpressBillDO> wrapper = new EntityWrapper<ExpressBillDO>();
        if(StringUtil.isNotEmpty(selectDTO.getCustomer())){
            wrapper.eq("customer",selectDTO.getCustomer());
        }
        if(StringUtil.isNotEmpty(selectDTO.getCourierAervices())){
            wrapper.eq("courier_aervices",selectDTO.getCourierAervices());
        }
        List<ExpressBillDO> list = expressBillMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = expressBillMapper.selectCount(wrapper);
        return new Page<ExpressBillDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExpressBillDO create(ExpressBillDTO insertDTO, Long adminId) throws ServiceException {
         Date now = new Date();
         ExpressBillDO insertDO = new ExpressBillDO();
         BeanUtils.copyProperties(insertDTO, insertDO);
         insertDO.setGmtUpdate(now);
         insertDO.setGmtCreate(now);
         if (expressBillMapper.insert(insertDO) > 0) {
             return insertDO;
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(ExpressBillDTO editDTO,Long adminId) throws ServiceException {
         Date now = new Date();
         ExpressBillDO updateDO = new ExpressBillDO();
         BeanUtils.copyProperties(editDTO, updateDO);
         updateDO.setGmtUpdate(now);
         if (expressBillMapper.updateById(updateDO) > 0) {
             return "ok";
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }



    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<ExpressBillDTO> expressBillDTOS) throws ServiceException {
        Date now = new Date();
        expressBillDTOS = JSON.parseArray(JSONObject.toJSONString(expressBillDTOS), ExpressBillDTO.class);
        if (!CollectionUtils.isEmpty(expressBillDTOS)) {
            for (int i = 0; i < expressBillDTOS.size(); i++) {
                ExpressBillDO insertDO = new ExpressBillDO();
                ExpressBillDTO dto = expressBillDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                expressBillMapper.insert(insertDO);
            }
        }
    }



    @Override
    public String export(ExpressBillDTO expressBillDTO, HttpServletResponse response) throws Exception {

        ExcelUtil<ExpressBillDTO> util = new ExcelUtil<ExpressBillDTO>(ExpressBillDTO.class);
        return util.exportExcel(expressBillDTO.getExpressBillDTOS(), "快递业务");

    }




}
