package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.CollectionPaymentDO;
import com.iotechn.unimall.data.dto.CollectionPaymentDTO;
import com.iotechn.unimall.data.dto.CollectionPaymentTiDTO;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.ExpressBusinessDO;
import com.iotechn.unimall.data.dto.ExpressBusinessDTO;
import com.iotechn.unimall.data.mapper.ExpressBusinessMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.util.StringUtil;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class ExpressServiceImpl implements ExpressService {

    @Autowired
    private ExpressBusinessMapper expressBusinessMapper;

    @Override
    public boolean delete(Long id,  Long adminId) throws ServiceException {
        return expressBusinessMapper.deleteById(id) > 0;
    }

    @Override
    public Page<ExpressBusinessDO> list(ExpressBusinessDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<ExpressBusinessDO> wrapper = new EntityWrapper<ExpressBusinessDO>();
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getBusinessNo())) {
            wrapper.like("business_no", selectDTO.getBusinessNo());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getCourierAervices())) {
            wrapper.like("courier_aervices", selectDTO.getCourierAervices());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getCustomerNo())) {
            wrapper.like("customer_no", selectDTO.getCustomerNo());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getSender())) {
            wrapper.like("sender", selectDTO.getSender());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getAddressee())) {
            wrapper.like("addressee", selectDTO.getAddressee());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getGoods())) {
            wrapper.like("goods", selectDTO.getGoods());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getStatus())) {
            wrapper.eq("status", selectDTO.getStatus());
        }
        if (selectDTO != null && StringUtil.isNotEmpty(selectDTO.getStartDate())) {
            wrapper.and("DATE_FORMAT(express_date,'%Y%m%d') >= DATE_FORMAT('" + selectDTO.getStartDate() + "','%Y%m%d')");
        }
        if (selectDTO != null && StringUtil.isNotEmpty(selectDTO.getEndDate())) {
            wrapper.and("DATE_FORMAT(express_date,'%Y%m%d') <= DATE_FORMAT('" + selectDTO.getEndDate() + "','%Y%m%d')");

        }
        List<ExpressBusinessDO> list = expressBusinessMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = expressBusinessMapper.selectCount(wrapper);
        return new Page<ExpressBusinessDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ExpressBusinessDO create(ExpressBusinessDTO insertDTO, Long adminId) throws ServiceException {
         Date now = new Date();
         ExpressBusinessDO insertDO = new ExpressBusinessDO();
         BeanUtils.copyProperties(insertDTO, insertDO);
         insertDO.setGmtUpdate(now);
         insertDO.setGmtCreate(now);
         if (expressBusinessMapper.insert(insertDO) > 0) {
             return insertDO;
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(ExpressBusinessDTO editDTO,Long adminId) throws ServiceException {
         Date now = new Date();
         ExpressBusinessDO updateDO = new ExpressBusinessDO();
         BeanUtils.copyProperties(editDTO, updateDO);
         updateDO.setGmtUpdate(now);
         if (expressBusinessMapper.updateById(updateDO) > 0) {
             return "ok";
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }



    @Override
    public String export(ExpressBusinessDTO expressBusinessDTO, HttpServletResponse response) throws Exception {

            ExcelUtil<ExpressBusinessDTO> util = new ExcelUtil<ExpressBusinessDTO>(ExpressBusinessDTO.class);
            return util.exportExcel(expressBusinessDTO.getExpressBusinessDTOS(), "快递业务记录");

    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<ExpressBusinessDTO> expressBusinessDTOS) throws ServiceException {
        Date now = new Date();
//        List<CollectionPaymentDTO> collectionPaymentDTOS = insertDTO.getCollectionPaymentDTOList();
        expressBusinessDTOS = JSON.parseArray(JSONObject.toJSONString(expressBusinessDTOS), ExpressBusinessDTO.class);
        if (!CollectionUtils.isEmpty(expressBusinessDTOS)) {
            for (int i = 0; i < expressBusinessDTOS.size(); i++) {
                ExpressBusinessDO insertDO = new ExpressBusinessDO();
                ExpressBusinessDTO dto = expressBusinessDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                expressBusinessMapper.insert(insertDO);
            }
        }
    }


}
