package com.iotechn.unimall.admin.api.sys;

import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.dto.ExpressBillDTO;
import com.iotechn.unimall.data.dto.ProductSalesDTO;
import com.iotechn.unimall.data.model.Page;
import com.iotechn.unimall.data.domain.ForeignExchangeDO;
import com.iotechn.unimall.data.dto.ForeignExchangeDTO;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@HttpOpenApi(group = "admin.foreignexchange", description = "unimall_foreign_exchangeService")
public interface ForeignExchangeService {

    @HttpMethod(description = "删除", permission = "foreignExchange:foreignexchange:delete", permissionParentName = "其他", permissionName = "ForeignExchange")
    public boolean delete(
            @NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "id") Long id,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;


    @HttpMethod(description = "查询", permission = "foreignExchange:foreignexchange:list", permissionParentName = "其他", permissionName = "ForeignExchange")
    public Page<ForeignExchangeDO> list(
            @HttpParam(name = "ForeignExchangeDTO", type = HttpParamType.COMMON, description = "ForeignExchangeDTO") ForeignExchangeDTO selectDTO,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "foreignExchange:foreignexchange:create", permissionParentName = "其他", permissionName = "ForeignExchange")
    public ForeignExchangeDO create(
            @HttpParam(name = "ForeignExchangeDTO", type = HttpParamType.COMMON, description = "ForeignExchangeDTO") ForeignExchangeDTO insertDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "编辑", permission = "foreignExchange:foreignexchange:edit", permissionParentName = "其他", permissionName = "ForeignExchange")
    public String edit(
            @HttpParam(name = "ForeignExchangeDTO", type = HttpParamType.COMMON, description = "ForeignExchangeDTO") ForeignExchangeDTO editDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "foreignExchange:foreignExchange:createAll", permissionParentName = "其他", permissionName = "ForeignExchange")
    public void createAll(
            @HttpParam(name = "ForeignExchangeDTO", type = HttpParamType.COMMON, description = "ForeignExchangeDTO") List<ForeignExchangeDTO> foreignExchangeDTOS) throws ServiceException;




    @HttpMethod(description = "导出", permission = "foreignExchange:foreignExchange:export", permissionParentName = "其他", permissionName = "ForeignExchange")
    public String export(
            @HttpParam(name = "ForeignExchangeDTO", type = HttpParamType.COMMON, description = "ForeignExchangeDTO") ForeignExchangeDTO foreignExchangeDTO,
            @HttpParam(name = "HttpServletResponse", type = HttpParamType.COMMON, description = "response") HttpServletResponse response) throws Exception;



}