package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.ExpressBusinessDO;
import com.iotechn.unimall.data.dto.ExpressBillDTO;
import com.iotechn.unimall.data.dto.ExpressBusinessDTO;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.ForeignExchangeDO;
import com.iotechn.unimall.data.dto.ForeignExchangeDTO;
import com.iotechn.unimall.data.mapper.ForeignExchangeMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import tk.mybatis.mapper.util.StringUtil;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class ForeignExchangeServiceImpl implements ForeignExchangeService {

    @Autowired
    private ForeignExchangeMapper foreignExchangeMapper;

    @Override
    public boolean delete(Long id,  Long adminId) throws ServiceException {
        return foreignExchangeMapper.deleteById(id) > 0;
    }

    @Override
    public Page<ForeignExchangeDO> list(ForeignExchangeDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<ForeignExchangeDO> wrapper = new EntityWrapper<ForeignExchangeDO>();
        if(StringUtil.isNotEmpty(selectDTO.getCustomerNo())){
            wrapper.eq("customer_no",selectDTO.getCustomerNo());
        }
        List<ForeignExchangeDO> list = foreignExchangeMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = foreignExchangeMapper.selectCount(wrapper);
        return new Page<ForeignExchangeDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ForeignExchangeDO create(ForeignExchangeDTO insertDTO, Long adminId) throws ServiceException {
         Date now = new Date();
         ForeignExchangeDO insertDO = new ForeignExchangeDO();
         BeanUtils.copyProperties(insertDTO, insertDO);
         insertDO.setGmtUpdate(now);
         insertDO.setGmtCreate(now);
         if (foreignExchangeMapper.insert(insertDO) > 0) {
             return insertDO;
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(ForeignExchangeDTO editDTO,Long adminId) throws ServiceException {
         Date now = new Date();
         ForeignExchangeDO updateDO = new ForeignExchangeDO();
         BeanUtils.copyProperties(editDTO, updateDO);
         updateDO.setGmtUpdate(now);
         if (foreignExchangeMapper.updateById(updateDO) > 0) {
             return "ok";
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<ForeignExchangeDTO> foreignExchangeDTOS) throws ServiceException {
        Date now = new Date();
        foreignExchangeDTOS = JSON.parseArray(JSONObject.toJSONString(foreignExchangeDTOS), ForeignExchangeDTO.class);
        if (!CollectionUtils.isEmpty(foreignExchangeDTOS)) {
            for (int i = 0; i < foreignExchangeDTOS.size(); i++) {
                ForeignExchangeDO insertDO = new ForeignExchangeDO();
                ForeignExchangeDTO dto = foreignExchangeDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                foreignExchangeMapper.insert(insertDO);
            }
        }
    }


    @Override
    public String export(ForeignExchangeDTO foreignExchangeDTO, HttpServletResponse response) throws Exception {

        ExcelUtil<ForeignExchangeDTO> util = new ExcelUtil<ForeignExchangeDTO>(ForeignExchangeDTO.class);
        return util.exportExcel(foreignExchangeDTO.getForeignExchangeDTOS(), "外汇信息");

    }



}
