package com.iotechn.unimall.admin.api.sys;


import cn.hutool.poi.excel.ExcelUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.core.util.ExcelUtils;
import com.iotechn.unimall.core.util.StringUtils;
import com.iotechn.unimall.data.domain.ForeignExchangeDO;
import com.iotechn.unimall.data.domain.MaritimeDetailDO;
import com.iotechn.unimall.data.dto.ForeignExchangeDTO;
import com.iotechn.unimall.data.dto.MaritimeDetailDTO;
import com.iotechn.unimall.data.mapper.MaritimeDetailMapper;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.MaritimeAdministrationDO;
import com.iotechn.unimall.data.dto.MaritimeAdministrationDTO;
import com.iotechn.unimall.data.mapper.MaritimeAdministrationMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class MaritimeAdministrationServiceImpl implements MaritimeAdministrationService {

    @Autowired
    private MaritimeAdministrationMapper maritimeAdministrationMapper;

    @Autowired
    private MaritimeDetailMapper maritimeDetailMapper;

    @Override
    public boolean delete(Long id, Long adminId) throws ServiceException {
        return maritimeAdministrationMapper.deleteById(id) > 0;
    }

    @Override
    public Page<MaritimeAdministrationDO> list(MaritimeAdministrationDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<MaritimeAdministrationDO> wrapper = new EntityWrapper<MaritimeAdministrationDO>();
        if(selectDTO!=null && StringUtils.isNotEmpty(selectDTO.getContainerNo())){
            wrapper.eq("container_no",selectDTO.getContainerNo());
        }
        if(selectDTO!=null && StringUtils.isNotEmpty(selectDTO.getCustomerNo())){
            wrapper.eq("customer_no",selectDTO.getCustomerNo());
        }
        List<MaritimeAdministrationDO> list = maritimeAdministrationMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        List<MaritimeAdministrationDO> list1= new ArrayList<>();
        if (!CollectionUtils.isEmpty(list)) {
            list.forEach(maritimeAdministrationDO -> {
                List<MaritimeDetailDO> maritimeDetailDOS = maritimeDetailMapper.selectList(new EntityWrapper<MaritimeDetailDO>()
                        .eq("info_id", maritimeAdministrationDO.getId()));
                maritimeAdministrationDO.setMaritimeDetailDOS(maritimeDetailDOS);
            });
        }
        Integer count = maritimeAdministrationMapper.selectCount(wrapper);
        return new Page<MaritimeAdministrationDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public MaritimeAdministrationDO create(MaritimeAdministrationDTO insertDTO, Long adminId) throws ServiceException {
        Date now = new Date();
        MaritimeAdministrationDO insertDO = new MaritimeAdministrationDO();
        BeanUtils.copyProperties(insertDTO, insertDO);
        insertDO.setGmtUpdate(now);
        insertDO.setGmtCreate(now);
        if (maritimeAdministrationMapper.insert(insertDO) > 0) {
            // 新增详情
            List<MaritimeDetailDTO> maritimeDetailDTOS = insertDTO.getMaritimeDetailDTOS();
            if (!CollectionUtils.isEmpty(maritimeDetailDTOS)) {
                for (MaritimeDetailDTO maritimeDetailDTO : maritimeDetailDTOS) {
                    maritimeDetailDTO.setInfoId(insertDO.getId());
                    MaritimeDetailDO maritimeDetailDO = new MaritimeDetailDO();
                    BeanUtils.copyProperties(maritimeDetailDTO, maritimeDetailDO);
                    maritimeDetailMapper.insert(maritimeDetailDO);
                }
            }
            return insertDO;
        }
        throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(MaritimeAdministrationDTO editDTO, Long adminId) throws ServiceException {
        Date now = new Date();
        MaritimeAdministrationDO updateDO = new MaritimeAdministrationDO();
        BeanUtils.copyProperties(editDTO, updateDO);
        updateDO.setGmtUpdate(now);
        if (maritimeAdministrationMapper.updateById(updateDO) > 0) {
            maritimeDetailMapper.delete(new EntityWrapper<MaritimeDetailDO>()
                    .eq("info_id", updateDO.getId()));
            List<MaritimeDetailDTO> maritimeDetailDTOS = editDTO.getMaritimeDetailDTOS();
            if (!CollectionUtils.isEmpty(maritimeDetailDTOS)) {
                for (MaritimeDetailDTO maritimeDetailDTO : maritimeDetailDTOS) {
                    maritimeDetailDTO.setInfoId(updateDO.getId());
                    MaritimeDetailDO maritimeDetailDO = new MaritimeDetailDO();
                    BeanUtils.copyProperties(maritimeDetailDTO, maritimeDetailDO);
                    maritimeDetailMapper.insert(maritimeDetailDO);
                }
            }
            return "ok";
        }
        throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    public String export(MaritimeAdministrationDTO maritimeAdministrationDTO, HttpServletResponse response) {
        // 表头处理
        List<Object> head = Arrays.asList("柜号","客户编号", "快递公司", "已收到单号", "内件明细", "实重", "长", "宽", "高", "体积重", "包裹数", "人民币", "欧元");
        // 汇总集合
        List<List<Object>> sheetDateList = new ArrayList<>();
        sheetDateList.add(head);
        //  导出信息处理
        Wrapper<MaritimeAdministrationDO> wrapper = new EntityWrapper<MaritimeAdministrationDO>();
        List<MaritimeAdministrationDO> list = maritimeAdministrationMapper.selectList(wrapper);
        if (!CollectionUtils.isEmpty(list)) {
            list.forEach(maritimeAdministrationDO -> {
                List<MaritimeDetailDO> maritimeDetailDOS = maritimeDetailMapper.selectList(new EntityWrapper<MaritimeDetailDO>()
                        .eq("info_id", maritimeAdministrationDO.getId()));
                if (!CollectionUtils.isEmpty(maritimeDetailDOS)) {
//                        maritimeDetailDO.setContainerNo(maritimeAdministrationDO.getContainerNo());
//                        maritimeDetailDO.setCustomerNo(maritimeAdministrationDO.getCustomerNo());
//                        maritimeDetailDO.setCount(maritimeAdministrationDO.getCount());
//                        maritimeDetailDO.setRmb(maritimeAdministrationDO.getRmb());
//                        maritimeDetailDO.setEuro(maritimeAdministrationDO.getEuro());
                    for (int i = 0; i < maritimeDetailDOS.size(); i++) {
                        MaritimeDetailDO maritimeDetailDO = maritimeDetailDOS.get(i);
                        if (i == 0) {
                            List<Object> objects = new ArrayList<>();
                            objects.add(maritimeAdministrationDO.getContainerNo());
                            objects.add(maritimeAdministrationDO.getCustomerNo());

                            objects.add(maritimeDetailDO.getCourierServicesCompany());
                            objects.add(maritimeDetailDO.getReceivedNo());
                            objects.add(maritimeDetailDO.getInternalDetails());
                            objects.add(maritimeDetailDO.getWeight());
                            objects.add(maritimeDetailDO.getLong1());
                            objects.add(maritimeDetailDO.getWide());
                            objects.add(maritimeDetailDO.getHeight());
                            objects.add(maritimeDetailDO.getBulkWeight());

                            objects.add(maritimeAdministrationDO.getCount());
                            objects.add(maritimeAdministrationDO.getRmb());
                            objects.add(maritimeAdministrationDO.getEuro());

                            sheetDateList.add(objects);
                        } else {
                            List<Object> objects = new ArrayList<>();
                            objects.add(ExcelUtils.ROW_MERGE);
                            objects.add(ExcelUtils.ROW_MERGE);

                            objects.add(maritimeDetailDO.getCourierServicesCompany());
                            objects.add(maritimeDetailDO.getReceivedNo());
                            objects.add(maritimeDetailDO.getInternalDetails());
                            objects.add(maritimeDetailDO.getWeight());
                            objects.add(maritimeDetailDO.getLong1());
                            objects.add(maritimeDetailDO.getWide());
                            objects.add(maritimeDetailDO.getHeight());
                            objects.add(maritimeDetailDO.getBulkWeight());

                            objects.add(ExcelUtils.ROW_MERGE);
                            objects.add(ExcelUtils.ROW_MERGE);
                            objects.add(ExcelUtils.ROW_MERGE);

                            sheetDateList.add(objects);
                        }
                    }


                }
            });
        }

        return ExcelUtils.export(response,"海运清单",sheetDateList);

    }

    @Override
    public MaritimeAdministrationDO getInfo(Long id) throws ServiceException {
        MaritimeAdministrationDO maritimeAdministrationDO = maritimeAdministrationMapper.selectById(id);
        if (maritimeAdministrationDO != null) {
            List<MaritimeDetailDO> maritimeDetailDOS = maritimeDetailMapper.selectList(new EntityWrapper<MaritimeDetailDO>()
                    .eq("info_id", id));
            maritimeAdministrationDO.setMaritimeDetailDOS(maritimeDetailDOS);
        }
        return maritimeAdministrationDO;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<MaritimeAdministrationDTO> maritimeAdministrationDTOS) throws ServiceException {
        Date now = new Date();
        maritimeAdministrationDTOS = JSON.parseArray(JSONObject.toJSONString(maritimeAdministrationDTOS), MaritimeAdministrationDTO.class);
        if (!CollectionUtils.isEmpty(maritimeAdministrationDTOS)) {
            for (int i = 0; i < maritimeAdministrationDTOS.size(); i++) {
                MaritimeAdministrationDO insertDO = new MaritimeAdministrationDO();
                MaritimeAdministrationDTO dto = maritimeAdministrationDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                maritimeAdministrationMapper.insert(insertDO);
                // 详情
                List<MaritimeDetailDTO> maritimeDetailDTOS = dto.getMaritimeDetailDTOS();
                if(!CollectionUtils.isEmpty(maritimeDetailDTOS)){
                    for(int j=0;j<maritimeDetailDTOS.size();j++){
                        MaritimeDetailDO insertDetailDO = new MaritimeDetailDO();
                        MaritimeDetailDTO dtoDetail = maritimeDetailDTOS.get(j);
                        BeanUtils.copyProperties(dtoDetail, insertDetailDO);
                        insertDetailDO.setInfoId(insertDO.getId());
                        insertDetailDO.setGmtUpdate(now);
                        insertDetailDO.setGmtCreate(now);
                        insertDetailDO.setStatus(0);
                        maritimeDetailMapper.insert(insertDetailDO);
                    }
                }
            }
        }
    }



}
