package com.iotechn.unimall.admin.api.sys;

import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.dto.ExpressBillDTO;
import com.iotechn.unimall.data.dto.ForeignExchangeDTO;
import com.iotechn.unimall.data.model.Page;
import com.iotechn.unimall.data.domain.ProductSalesDO;
import com.iotechn.unimall.data.dto.ProductSalesDTO;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@HttpOpenApi(group = "admin.productsales", description = "unimall_product_salesService")
public interface ProductSalesService {

    @HttpMethod(description = "删除", permission = "productSales:productsales:delete", permissionParentName = "其他", permissionName = "ProductSales")
    public boolean delete(
            @NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "id") Long id,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;


    @HttpMethod(description = "查询", permission = "productSales:productsales:list", permissionParentName = "其他", permissionName = "ProductSales")
    public Page<ProductSalesDO> list(
            @HttpParam(name = "ProductSalesDTO", type = HttpParamType.COMMON, description = "ProductSalesDTO") ProductSalesDTO selectDTO,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "productSales:productsales:create", permissionParentName = "其他", permissionName = "ProductSales")
    public ProductSalesDO create(
            @HttpParam(name = "ProductSalesDTO", type = HttpParamType.COMMON, description = "ProductSalesDTO") ProductSalesDTO insertDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "编辑", permission = "productSales:productsales:edit", permissionParentName = "其他", permissionName = "ProductSales")
    public String edit(
            @HttpParam(name = "ProductSalesDTO", type = HttpParamType.COMMON, description = "ProductSalesDTO") ProductSalesDTO editDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "productSales:productsales:createAll", permissionParentName = "其他", permissionName = "ProductSales")
    public void createAll(
            @HttpParam(name = "ProductSalesDTO", type = HttpParamType.COMMON, description = "ProductSalesDTO") List<ProductSalesDTO> productSalesDTOS) throws ServiceException;


    @HttpMethod(description = "导出", permission = "productSales:productsales:export", permissionParentName = "其他", permissionName = "ProductSales")
    public String export(
            @HttpParam(name = "ProductSalesDTO", type = HttpParamType.COMMON, description = "ProductSalesDTO") ProductSalesDTO productSalesDTO,
            @HttpParam(name = "HttpServletResponse", type = HttpParamType.COMMON, description = "response") HttpServletResponse response) throws Exception;



}