package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.ForeignExchangeDO;
import com.iotechn.unimall.data.dto.ExpressBillDTO;
import com.iotechn.unimall.data.dto.ForeignExchangeDTO;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.ProductSalesDO;
import com.iotechn.unimall.data.dto.ProductSalesDTO;
import com.iotechn.unimall.data.mapper.ProductSalesMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class ProductSalesServiceImpl implements ProductSalesService {

    @Autowired
    private ProductSalesMapper productSalesMapper;

    @Override
    public boolean delete(Long id,  Long adminId) throws ServiceException {
        return productSalesMapper.deleteById(id) > 0;
    }

    @Override
    public Page<ProductSalesDO> list(ProductSalesDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<ProductSalesDO> wrapper = new EntityWrapper<ProductSalesDO>();
        if(!StringUtils.isEmpty(selectDTO.getSaleNo())){
            wrapper.eq("sale_no",selectDTO.getSaleNo());
        }
        if(!StringUtils.isEmpty(selectDTO.getCustomer())){
            wrapper.eq("customer",selectDTO.getCustomer());
        }
        if(!StringUtils.isEmpty(selectDTO.getTradeName())){
            wrapper.eq("trade_name",selectDTO.getTradeName());
        }
        List<ProductSalesDO> list = productSalesMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = productSalesMapper.selectCount(wrapper);
        return new Page<ProductSalesDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ProductSalesDO create(ProductSalesDTO insertDTO, Long adminId) throws ServiceException {
         Date now = new Date();
         ProductSalesDO insertDO = new ProductSalesDO();
         BeanUtils.copyProperties(insertDTO, insertDO);
         insertDO.setGmtUpdate(now);
         insertDO.setGmtCreate(now);
         if (productSalesMapper.insert(insertDO) > 0) {
             return insertDO;
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(ProductSalesDTO editDTO,Long adminId) throws ServiceException {
         Date now = new Date();
         ProductSalesDO updateDO = new ProductSalesDO();
         BeanUtils.copyProperties(editDTO, updateDO);
         updateDO.setGmtUpdate(now);
         if (productSalesMapper.updateById(updateDO) > 0) {
             return "ok";
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }



    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<ProductSalesDTO> productSalesDTOS) throws ServiceException {
        Date now = new Date();
        productSalesDTOS = JSON.parseArray(JSONObject.toJSONString(productSalesDTOS), ProductSalesDTO.class);
        if (!CollectionUtils.isEmpty(productSalesDTOS)) {
            for (int i = 0; i < productSalesDTOS.size(); i++) {
                ProductSalesDO insertDO = new ProductSalesDO();
                ProductSalesDTO dto = productSalesDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                productSalesMapper.insert(insertDO);
            }
        }
    }

    @Override
    public String export(ProductSalesDTO productSalesDTO, HttpServletResponse response) throws Exception {

        ExcelUtil<ProductSalesDTO> util = new ExcelUtil<ProductSalesDTO>(ProductSalesDTO.class);
        return util.exportExcel(productSalesDTO.getProductSalesDTOS(), "产品销售");

    }

}
