package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.ExpressBusinessDO;
import com.iotechn.unimall.data.domain.StockManagementDO;
import com.iotechn.unimall.data.dto.ExpressBusinessDTO;
import com.iotechn.unimall.data.dto.StockManagementDTO;
import com.iotechn.unimall.data.mapper.StockManagementMapper;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.SettlementManagementDO;
import com.iotechn.unimall.data.dto.SettlementManagementDTO;
import com.iotechn.unimall.data.mapper.SettlementManagementMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import tk.mybatis.mapper.util.StringUtil;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class SettlementServiceImpl implements SettlementService {

    @Autowired
    private SettlementManagementMapper settlementManagementMapper;
    @Autowired
    private StockManagementMapper stockManagementMapper;

    @Override
    public boolean delete(Long id, Long adminId) throws ServiceException {
        return settlementManagementMapper.deleteById(id) > 0;
    }

    @Override
    public Page<SettlementManagementDO> list(SettlementManagementDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<SettlementManagementDO> wrapper = new EntityWrapper<SettlementManagementDO>();
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getTradeName())) {
            wrapper.like("trade_name", selectDTO.getTradeName());
        }
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getStatus())) {
            wrapper.eq("status", selectDTO.getStatus());
        }
        if (selectDTO != null && StringUtil.isNotEmpty(selectDTO.getStartDate())) {
            wrapper.and("DATE_FORMAT(closing_date,'%Y%m%d') >= DATE_FORMAT('" + selectDTO.getStartDate() + "','%Y%m%d')");
        }
        if (selectDTO != null && StringUtil.isNotEmpty(selectDTO.getEndDate())) {
            wrapper.and("DATE_FORMAT(closing_date,'%Y%m%d') <= DATE_FORMAT('" + selectDTO.getEndDate() + "','%Y%m%d')");

        }
        List<SettlementManagementDO> list = settlementManagementMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = settlementManagementMapper.selectCount(wrapper);
        return new Page<SettlementManagementDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public SettlementManagementDO create(SettlementManagementDTO insertDTO, Long adminId) throws ServiceException {
        Date now = new Date();
        SettlementManagementDO insertDO = new SettlementManagementDO();
        BeanUtils.copyProperties(insertDTO, insertDO);
        insertDO.setGmtUpdate(now);
        insertDO.setGmtCreate(now);
        StockManagementDO stockManagementDO = new StockManagementDO();
        stockManagementDO.setTradeName(insertDO.getTradeName());
        StockManagementDO stockManagementDO1 = stockManagementMapper.selectOne(stockManagementDO);
        if (stockManagementDO1 != null && (stockManagementDO1.getNum() - insertDO.getNum() >= 0)) {

            stockManagementDO1.setNum(stockManagementDO1.getNum() - insertDO.getNum());
            stockManagementMapper.updateById(stockManagementDO1);
        } else {
            throw new AdminServiceException(ExceptionDefinition.FLAT_COUNT_ERROR);
        }
        if (settlementManagementMapper.insert(insertDO) > 0) {

            return insertDO;
        }
        throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(SettlementManagementDTO editDTO, Long adminId) throws ServiceException {
        Date now = new Date();
        SettlementManagementDO updateDO = new SettlementManagementDO();
        BeanUtils.copyProperties(editDTO, updateDO);
        updateDO.setGmtUpdate(now);
        if (settlementManagementMapper.updateById(updateDO) > 0) {
            return "ok";
        }
        throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }


    @Override
    public String export(SettlementManagementDTO settlementManagementDTO, HttpServletResponse response) throws Exception {

        ExcelUtil<SettlementManagementDTO> util = new ExcelUtil<SettlementManagementDTO>(SettlementManagementDTO.class);
        return util.exportExcel(settlementManagementDTO.getSettlementManagementDTOS(), "商品结算记录");

    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<SettlementManagementDTO> settlementManagementDTOS) throws ServiceException {
        Date now = new Date();
//        List<CollectionPaymentDTO> collectionPaymentDTOS = insertDTO.getCollectionPaymentDTOList();
        settlementManagementDTOS = JSON.parseArray(JSONObject.toJSONString(settlementManagementDTOS), SettlementManagementDTO.class);
        if (!CollectionUtils.isEmpty(settlementManagementDTOS)) {
            for (int i = 0; i < settlementManagementDTOS.size(); i++) {
                SettlementManagementDO insertDO = new SettlementManagementDO();
                SettlementManagementDTO dto = settlementManagementDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                settlementManagementMapper.insert(insertDO);
            }
        }
    }


}
