package com.iotechn.unimall.admin.api.sys;

import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.dto.SettlementManagementDTO;
import com.iotechn.unimall.data.model.Page;
import com.iotechn.unimall.data.domain.StockManagementDO;
import com.iotechn.unimall.data.dto.StockManagementDTO;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@HttpOpenApi(group = "admin.stock", description = "unimall_stock_managementService")
public interface StockService {

    @HttpMethod(description = "删除", permission = "stock:stock:delete", permissionParentName = "其他", permissionName = "Stock")
    public boolean delete(
            @NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "id") Long id,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;


    @HttpMethod(description = "查询商品", permission = "stock:stock:stockList", permissionParentName = "其他", permissionName = "Stock")
    public  List<StockManagementDO> stockList() throws ServiceException;


    @HttpMethod(description = "查询", permission = "stock:stock:list", permissionParentName = "其他", permissionName = "Stock")
    public Page<StockManagementDO> list(
            @HttpParam(name = "StockManagementDTO", type = HttpParamType.COMMON, description = "StockManagementDTO") StockManagementDTO selectDTO,
            @HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
            @HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "添加", permission = "stock:stock:create", permissionParentName = "其他", permissionName = "Stock")
    public StockManagementDO create(
            @HttpParam(name = "StockManagementDTO", type = HttpParamType.COMMON, description = "StockManagementDTO") StockManagementDTO insertDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;

    @HttpMethod(description = "编辑", permission = "stock:stock:edit", permissionParentName = "其他", permissionName = "Stock")
    public String edit(
            @HttpParam(name = "StockManagementDTO", type = HttpParamType.COMMON, description = "StockManagementDTO") StockManagementDTO editDTO,
            @NotNull @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "管理员ID") Long adminId) throws ServiceException;



    @HttpMethod(description = "导出", permission = "stock:stock:export", permissionParentName = "其他", permissionName = "Settlement")
    public String export(
            @HttpParam(name = "StockManagementDTO", type = HttpParamType.COMMON, description = "StockManagementDTO") StockManagementDTO stockManagementDTO,
            @HttpParam(name = "HttpServletResponse", type = HttpParamType.COMMON, description = "response") HttpServletResponse response) throws Exception;


    @HttpMethod(description = "添加", permission = "stock:stock:createAll", permissionParentName = "其他", permissionName = "Settlement")
    public void createAll(
            @HttpParam(name = "StockManagementDTO", type = HttpParamType.COMMON, description = "StockManagementDTO") List<StockManagementDTO> stockManagementDTOS) throws ServiceException;

}