package com.iotechn.unimall.admin.api.sys;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.iotechn.unimall.core.exception.AdminServiceException;
import com.iotechn.unimall.core.exception.ExceptionDefinition;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.SettlementManagementDO;
import com.iotechn.unimall.data.dto.SettlementManagementDTO;
import com.iotechn.unimall.data.model.Page;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.iotechn.unimall.data.domain.StockManagementDO;
import com.iotechn.unimall.data.dto.StockManagementDTO;
import com.iotechn.unimall.data.mapper.StockManagementMapper;
import com.iotechn.unimall.data.util.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.BeanUtils;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.servlet.http.HttpServletResponse;
import java.util.Date;
import java.util.List;

/**
 * Generate Code By Unimall
 */
@Service
public class StockServiceImpl implements StockService {

    @Autowired
    private StockManagementMapper stockManagementMapper;

    @Override
    public boolean delete(Long id,  Long adminId) throws ServiceException {
        return stockManagementMapper.deleteById(id) > 0;
    }

    @Override
    public List<StockManagementDO> stockList() throws ServiceException {
        Wrapper<StockManagementDO> wrapper = new EntityWrapper<StockManagementDO>();
        wrapper.groupBy("trade_name");
        List<StockManagementDO> list = stockManagementMapper.selectList(wrapper);
        return list;
    }




    @Override
    public Page<StockManagementDO> list(StockManagementDTO selectDTO, Integer page, Integer limit, Long adminId) throws ServiceException {
        Wrapper<StockManagementDO> wrapper = new EntityWrapper<StockManagementDO>();
        if (selectDTO != null && !StringUtils.isEmpty(selectDTO.getTradeName())) {
            wrapper.like("trade_name", selectDTO.getTradeName());
        }
        List<StockManagementDO> list = stockManagementMapper.selectPage(new RowBounds((page - 1) * limit, limit), wrapper);
        Integer count = stockManagementMapper.selectCount(wrapper);
        return new Page<StockManagementDO>(list, page, limit, count);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public StockManagementDO create(StockManagementDTO insertDTO, Long adminId) throws ServiceException {
         Date now = new Date();
         StockManagementDO insertDO = new StockManagementDO();
         BeanUtils.copyProperties(insertDTO, insertDO);
         insertDO.setGmtUpdate(now);
         insertDO.setGmtCreate(now);
        Wrapper<StockManagementDO> wrapper = new EntityWrapper<StockManagementDO>();
        if (insertDTO != null && !StringUtils.isEmpty(insertDTO.getTradeName())) {
            wrapper.eq("trade_name", insertDTO.getTradeName());
        }
        List<StockManagementDO> stockManagementDO1 = stockManagementMapper.selectList(wrapper);
        if(!CollectionUtils.isEmpty(stockManagementDO1)){
            throw new AdminServiceException(ExceptionDefinition.IN_STORE_ERROR);
        }
         if (stockManagementMapper.insert(insertDO) > 0) {
             return insertDO;
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String edit(StockManagementDTO editDTO,Long adminId) throws ServiceException {
         Date now = new Date();
         StockManagementDO updateDO = new StockManagementDO();
         BeanUtils.copyProperties(editDTO, updateDO);
         updateDO.setGmtUpdate(now);
         if (stockManagementMapper.updateById(updateDO) > 0) {
             return "ok";
         }
         throw new AdminServiceException(ExceptionDefinition.ADMIN_UNKNOWN_EXCEPTION);
    }



    @Override
    public String export(StockManagementDTO stockManagementDTO, HttpServletResponse response) throws Exception {

        ExcelUtil<StockManagementDTO> util = new ExcelUtil<StockManagementDTO>(StockManagementDTO.class);
        return util.exportExcel(stockManagementDTO.getStockManagementDTOS(), "库存管理记录");

    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void createAll(List<StockManagementDTO> stockManagementDTOS) throws ServiceException {
        Date now = new Date();
//        List<CollectionPaymentDTO> collectionPaymentDTOS = insertDTO.getCollectionPaymentDTOList();
        stockManagementDTOS = JSON.parseArray(JSONObject.toJSONString(stockManagementDTOS), StockManagementDTO.class);
        if (!CollectionUtils.isEmpty(stockManagementDTOS)) {
            for (int i = 0; i < stockManagementDTOS.size(); i++) {
                StockManagementDO insertDO = new StockManagementDO();
                StockManagementDTO dto = stockManagementDTOS.get(i);
                BeanUtils.copyProperties(dto, insertDO);
                insertDO.setGmtUpdate(now);
                insertDO.setGmtCreate(now);
                insertDO.setStatus(0);
                stockManagementMapper.insert(insertDO);
            }
        }
    }



}
